@@ -4,12 +4,9 @@
 ## This program is GPLed.  Please read the LICENSE file for more information.
 ## Copyright (C) 1996, Bitgate Software.
 
-#define	STRING_CHECK	"1"
-#define	FILE_CHECK	"2"
-
 sub check_exist {
 	local($type, $filename, $checkfor, $cfile) = @_;
-	if ($type eq FILE_CHECK) {
+	if ($type eq "2") {
 		if (-e $filename) {
 			return 1;
 		} else {
@@ -17,7 +14,7 @@ sub check_exist {
 		}
 	}
 
-	if ($type eq STRING_CHECK) {
+	if ($type eq "1") {
 		if (-e $filename) {
 			$clean = 0;
 			open(IF, $filename);
