@@ -11,28 +11,24 @@
 ##	Include "require 'question.pl'" in your Perl program, and call
 ##	ask_question to ask your question.
 
-#define	BOOLEAN_QUESTION	"1"
-#define	STRING_QUESTION		"2"
-#define	STANDARD_QUESTION	"3"
-
 sub ask_question {
 	local($question, $value, $type, $cfile) = @_;
 
 repeat_ask:
 	print "$question ";
-	if ($type eq BOOLEAN_QUESTION) {
+	if ($type eq "1") {
 		$value =~ tr/a-z/A-Z/;
 		print (($value eq "Y") ? "[Y/n/?] " : "[y/N/?] ");
-	} elsif ($type eq STRING_QUESTION) {
+	} elsif ($type eq "2") {
 		print "[$value] ";
-	} elsif ($type eq STANDARD_QUESTION) {
+	} elsif ($type eq "3") {
 		print "$value ";
 	}
 
 	$entry = <stdin>;
 	chop($entry);
 
-	if ($type eq BOOLEAN_QUESTION) {
+	if ($type eq "1") {
 		$entry =~ tr/a-z/A-Z/;
 		if ($entry eq "") {
 			$entry = $value;
@@ -44,7 +40,7 @@ repeat_ask:
 			&disp_file($cfile);
 			goto repeat_ask;
 		}
-	} elsif (($type eq STRING_QUESTION) || ($type eq STANDARD_QUESTION)) {
+	} elsif (($type eq "2") || ($type eq "3")) {
 		if ($entry eq "") {
 			$entry = $value;
 		}
