@@ -25,7 +25,6 @@
 #include <unistd.h>
 #include <netdb.h>
 #include <errno.h>
-#include <utmp.h>
 #include <ctype.h>
 #include <time.h>
 #include <pwd.h>
@@ -38,11 +37,44 @@
 
 #include "config.h"
 
+#ifdef SUNOS
+#include <utmpx.h>
+#include <unistd.h>
+#define utmp utmpx
+#define ut_time ut_xtime
+#define getutent getutxent
+#define _PATH_UTMP UTMPX_FILE
+#if (SUNOS == 55)
+#define snprintf __snprintf
+#endif
+#else
+#include <utmp.h>
+#endif
+
+#if !defined(UT_USERSIZE) ||  !defined(UT_HOSTSIZE) ||  !defined(UT_LINESIZE) ||  !defined(UT_NAMESIZE)
+struct utmp foo_utmp;
+#endif
+
+#ifndef UT_USERSIZE
+#define UT_USERSIZE sizeof(foo_utmp.ut_name)
+#endif
+#ifndef UT_HOSTSIZE
+#define UT_HOSTSIZE sizeof(foo_utmp.ut_host)
+#endif
+#ifndef UT_LINESIZE
+#define UT_LINESIZE sizeof(foo_utmp.ut_line)
+#endif
+#ifndef UT_NAMESIZE
+#define UT_NAMESIZE sizeof(foo_utmp.ut_user)
+#endif
+
 #define	BOOL	int
 
 #define	TRUE	1
 #define	FALSE	0
 
+#define MAX_POPEN_BUF	10 * 1024 * 1024 /* max. 10 MB buffer */
+
 /* First configuration option bit pair */
 #define	SHOW_SYSLOG	0x0001	/* Log all errors to the syslog daemon	*/
 #define	SHOW_TOP	0x0002	/* Show the top file on a finger req.	*/
@@ -61,7 +93,7 @@
 #define	SHOW_MRDATE	0x4000	/* Show the last day that mail was read	*/
 #define	SHOW_FROM	0x8000	/* Show where the last login originated	*/
 
-/* Second configuration option bit pair -- ALWAYS room for improvement */
+/* Second configuration option bit pair */
 #define	SHOW_PLAN	0x0001	/* Show the user's plan file		*/
 #define	SHOW_PROJECT	0x0002	/* Show the user's project file		*/
 #define	SHOW_PGPKEY	0x0004	/* Show the user's PGP key file		*/
@@ -79,7 +111,7 @@
 #define	SHOW_ULISTONLY	0x4000	/* Allow for "userlist-only" fingers	*/
 #define	SHOW_NOBODY1413	0x8000	/* Allow for non-ident users to finger  */
 
-/* Third row of configuration bits */
+/* Third row of configuration bits -- ALWAYS room for improvement */
 #define	SHOW_LOG	0x0001	/* Allow for logging of all fingers	*/
 #define	SHOW_PARSING	0x0002	/* Allow for text line data parsing	*/
 #define	SHOW_USERLOG	0x0004	/* Allow for userlogging of all fingers */
@@ -88,6 +120,8 @@
 #define	SHOW_XFACE	0x0020	/* Allow display of xface files		*/
 #define	SHOW_HEADERS_FE	0x0040	/* Show headers if file exists		*/
 #define	SHOW_CREATE_FLG	0x0080	/* Create fingerlog file if file exists	*/
+#define	SHOW_CLOCK24	0x0100	/* Show time in clock 24 format         */
+#define	SHOW_CONFESSION	0x0200	/*          */
 
 /* Program exit states */
 #define	PROGRAM_OKAY	0	/* Program exited fine			*/
@@ -222,6 +256,8 @@ typedef struct {
     char *p_strings[80];	/* Program-related context print strings */
     char *finger_sites[80];	/* Finger sites that are queried */
     char *siglist[24];		/* Signal names and their errors */
+    char stime_format[25];	/* Short time format string */
+    char ltime_format[25];	/* Long time format string */
     FAKEUSERS fusers[40];	/* Fake user name listings */
     SERVICES services;		/* Services configuration display */
     int  config_bits1;		/* First row of configuration bits */
@@ -247,9 +283,13 @@ extern int trusted_host_num, rejected_host_num, forward_host_num,
 	   fakeuser_num, num_finger_sites, num_headers, local_port,
 	   remote_port, can_log;
 extern FILE *top_display, *bottom_display, *noname_display, *nouser_display,
-	    *identd_display;
+	    *rejected_display, *identd_display;
 extern BOOL local_finger, emulated;
 extern FILE *logfile;
+#ifdef DAEMON_MODE
+extern unsigned short listen_port;
+extern unsigned long listen_addr;
+#endif
 
 #include "defines.h"
 
