@@ -64,6 +64,7 @@ TYPEVAL finger_display[] = {
 	{ "REJECTED_BANNER", SHOW_REJECTED, 2 },
 	{ "SYSTEM_LIST", SHOW_SYSTEMLIST, 2 },
 	{ "NO_USER", SHOW_NOUSER, 2 },
+	{ "CLOCK24", SHOW_CLOCK24, 3},
 	{ "XFACE", SHOW_XFACE, 3 },
 	{ NULL, 0, 0 }
 };
@@ -83,6 +84,7 @@ TYPEVAL internal_config[] = {
 	{ "ALLOW_USERLOG", SHOW_USERLOG, 3 },
 	{ "ALLOW_EXECUTION", SHOW_EXEC, 3 },
 	{ "ALLOW_FAKEUSER_FINGER", SHOW_FAKEUSER, 3 },
+	{ "ALLOW_CONFESSION", SHOW_CONFESSION, 3 },
 	{ "ONLY_SHOW_HEADERS_IF_FILE_EXISTS", SHOW_HEADERS_FE, 3 },
 	{ "ONLY_CREATE_FINGERLOG_IF_FILE_EXISTS", SHOW_CREATE_FLG, 3 },
 	{ NULL, 0, 0 }
@@ -681,7 +683,7 @@ void do_config(char *str)
 void read_configuration(void)
 {
     PRIV_ROOT_START
-    file = fopen(CFINGER_CONF, "r");
+    file = fopen(CFINGERD_CONF, "r");
     PRIV_ROOT_END
 
     trusted_host_num = rejected_host_num = fakeuser_num = num_finger_sites = 0;
@@ -761,7 +763,15 @@ void check_blank_configurations(void)
     }
 
     if (prog_config.mailbox_file == NULL) {
-	prog_config.mailbox_file = (char *) malloc(17);
-	sprintf(prog_config.mailbox_file, "/usr/spool/mail/$USER");
+	prog_config.mailbox_file = (char *) malloc(sizeof(MAIL_SPOOL_DIR)+7);
+	sprintf(prog_config.mailbox_file, "%s/$USER", MAIL_SPOOL_DIR);
     }
 }
+
+/*
+ * Local variables:
+ *  c-indent-level: 4
+ *  c-basic-offset: 4
+ *  tab-width: 8
+ * End:
+ */
