@@ -13,6 +13,9 @@
  * GNU General Public License for more details.
  */
 
+#ifndef _DEFINES_H_
+#define _DEFINES_H_
+
 /* Error handler...  Or what seems to be.  :) */
 #define	CF_ERROR(x)	{ \
 			    printf("\n"); \
@@ -25,3 +28,7 @@
 /* Some defines to make adding in carriage returns easier... */
 #define	SEND_RAW_RETURN			{ printf("\n"); fflush(stdout); }
 #define	SEND_RAW_RETURN_NO_FLUSH	printf("\n");
+
+#define ERRORS_TO	"cfingerd@infodrom.north.de"
+
+#endif /* _DEFINES_H_ */
