@@ -4,7 +4,9 @@
 #ifdef BSD
 struct utmp *getutent();  /* returns next utmp file entry   */
 void setutent();
+#ifndef __FreeBSD__
 char *getdomainname(char *, size_t);
+#endif /* !__FreeBSD__ */
 #endif
 
 #endif
