@@ -29,6 +29,7 @@
 #ifndef _USE_BSD
 #define _USE_BSD 1
 #include <unistd.h>
+#include <grp.h>
 #undef _USE_BSD
 #else
 #include <unistd.h>
@@ -37,7 +38,7 @@
 /* Relinquish privileges temporarily for a setuid or setgid program
  * with the option of getting them back later.  This is done by swapping
  * the real and effective userid BSD style.  Call RELINQUISH_PRIVS once
- * at the beginning of the main program.  This will cause all operatons
+ * at the beginning of the main program.  This will cause all operations
  * to be executed with the real userid.  When you need the privileges
  * of the setuid/setgid invocation, call PRIV_START; when you no longer
  * need it, call PRIV_END.  Note that it is an error to call PRIV_START
@@ -72,40 +73,67 @@ uid_t real_uid, effective_uid;
 extern
 #endif
 gid_t real_gid, effective_gid;
+#ifndef MAIN
+extern
+#endif
+gid_t grouplist[1];
 
+
+#define NOBODY_PRIVS	USER_PRIVS (NOBODY_UID,NOBODY_GID)
+
+/*
+ * Switches real and effective uid/gid.
+ */
 #define RELINQUISH_PRIVS { \
 			      real_uid = getuid(); \
-			      effective_uid = NOBODY_UID; \
+			      effective_uid = geteuid(); \
 			      real_gid = getgid(); \
-			      effective_gid = NOBODY_GID; \
-			      setregid(real_gid, effective_gid); \
-			      setreuid(real_uid, effective_uid); \
+			      effective_gid = getegid(); \
+			      setregid(effective_gid, real_gid); \
+			      setreuid(effective_uid, real_uid); \
 		          }
 
+/*
+ * Restores saved real and effective uid/gid.
+ */
 #define PRIV_ROOT_START {\
-			    setreuid(effective_uid, real_uid); \
-			    setregid(effective_gid, real_gid); \
+			    setreuid(real_uid, 0); \
+			    setregid(real_gid, 0);
 
+/*
+ * Switches real and effective uid/gid back.
+ */
 #define PRIV_ROOT_END \
+			    setregid(0, real_gid); \
+			    setreuid(0, real_uid); \
+			}
+
+/*
+ * Switches to non priviliged uid/gid.  This is done by first
+ * switching back to priviliged uid/gid.  This means that real_uid and
+ * real_gid need to contain root uid/gid.  Only the effective uid is
+ * switched to non-priviliged.
+ */
+#define USER_PRIVS(a,b) {\
+			    setreuid(real_uid, 0); \
+			    setregid(real_gid, 0); \
+			    effective_uid = (a); \
+			    effective_gid = (b); \
+			    grouplist[0] = effective_gid; \
+			    setgroups(1, grouplist); \
 			    setregid(real_gid, effective_gid); \
 			    setreuid(real_uid, effective_uid); \
 			}
 
-#define USER_PRIVS(a,b) {\
-			setreuid(real_uid, 0); \
-			setregid(real_gid, 0); \
-			effective_uid = (a); \
-			effective_gid = (b); \
-			setregid(real_gid, effective_gid); \
-			setreuid(real_uid, effective_uid); \
-		    }
-
-#define NOBODY_PRIVS \
-			setreuid(real_uid, 0); \
-			setregid(real_gid, 0); \
-			effective_uid = NOBODY_UID; \
-			effective_gid = NOBODY_GID; \
-			setreuid(real_uid, effective_uid); \
-			setregid(real_gid, effective_gid);
+#define DROP_ALL_PRIVS(a,b) {\
+			    setreuid(real_uid, 0); \
+			    setregid(real_gid, 0); \
+			    effective_uid = (a); \
+			    effective_gid = (b); \
+			    grouplist[0] = effective_gid; \
+			    setgroups(1, grouplist); \
+			    setregid(effective_gid, effective_gid); \
+			    setreuid(effective_uid, effective_uid); \
+			}
 		
 #endif  /* _PRIVS_H_ */
