@@ -44,7 +44,7 @@ SLIST siglist[] = {
 	{SIGUSR1,	"SIGUSR1",	S_SIGUSR1,	FALSE},
 	{SIGSEGV,	"SIGSEGV",	S_SIGSEGV,	TRUE},
 	{SIGUSR2,	"SIGUSR2",	S_SIGUSR2,	FALSE},
-	{SIGPIPE,	"SIGPIPE",	S_SIGPIPE,	FALSE},
+	{SIGPIPE,	"SIGPIPE",	S_SIGPIPE,	TRUE},
 	{SIGALRM,	"SIGALRM",	S_SIGALRM,	FALSE},
 	{SIGTERM,	"SIGTERM",	S_SIGTERM,	TRUE},
 	{SIGCONT,	"SIGCONT",	S_SIGCONT,	FALSE},
@@ -80,7 +80,7 @@ void int_handler(int signo)
 	    caught = TRUE;
 
 	    if (siglist[i].fatal) {
-		printf("\nPlease report this bug to khollis@bitgate.com!\n");
+		printf("\nPlease report this bug to %s!\n", ERRORS_TO);
 		log(LOG_ERROR, "Signal (fatal): ", siglist[i].sigtype);
 	    } else {
 		if (siglist[i].value == SIGALRM) {
@@ -105,7 +105,7 @@ void int_handler(int signo)
 
     if (!caught) {
 	printf("Whoops, the program crashed.  Could not catch the signal type.\n");
-	printf("Please report this to khollis@bitgate.com.\n\n");
+	printf("Please report this to %s.\n\n", ERRORS_TO);
 	syslog(LOG_ERR, "SIGUNKNOWN caught");
 	(void) fflush(stdout);
 
@@ -135,3 +135,11 @@ void start_handler(void)
     for (i = 0; i < sigs; i++)
 	signal(signals[i], int_handler);
 }
+
+/*
+ * Local variables:
+ *  c-indent-level: 4
+ *  c-basic-offset: 4
+ *  tab-width: 8
+ * End:
+ */
