@@ -100,7 +100,7 @@ void show_stuff(char *user, int t1, int t2)
 	columns++;
 	snprintf(formatter, sizeof(formatter), "%%s%%-%d.%ds", (36 - strlen(prog_config.p_strings[t2])),
 		36);
-	printf(formatter, prog_config.p_strings[t2], user);
+	printf(formatter, prog_config.p_strings[t2], user?user:"");
 	do_columns();
     }
 }
@@ -814,11 +814,12 @@ void show_fingerinfo(char *user)
 {
     struct passwd *pwent;
     FILE *file;
-    char username[80], room[80], work_phone[80], home_phone[80],
-	 other[80], fn[80];
+    char *username=NULL, *room=NULL, *work_phone=NULL, *home_phone=NULL, *other=NULL;
+    char fn[80];
     BOOL qmail;
     char acctname[100];
     char *alias = NULL;
+    char *cp, *x;
 
     columns = 0;
     qmail = ( strcasecmp(prog_config.mailbox_file, "QMAIL") == 0);
@@ -845,14 +846,51 @@ void show_fingerinfo(char *user)
     nuid = pwent->pw_uid;
     ngid = pwent->pw_gid;
 
-    username[0] = 0;
-    room[0] = 0;
-    work_phone[0] = 0;
-    home_phone[0] = 0;
-    other[0] = 0;
-
-    sscanf(pwent->pw_gecos, "%[^,],%[^,],%[^,],%[^,],%[^\r\n]\r\n",
-	username, room, work_phone, home_phone, other);
+    cp = pwent->pw_gecos;
+    if ((x = index (cp, ',')) != NULL) { /* username */
+	if ((username = (char *)malloc (x-cp+1)) != NULL) {
+	    memset (username, 0, x-cp+1);
+	    strncpy (username, cp, x-cp);
+	}
+	cp = ++x;
+	if ((x = index (cp, ',')) != NULL) { /* room */
+	    if ((room = (char *)malloc (x-cp+1)) != NULL) {
+		memset (room, 0, x-cp+1);
+		strncpy (room, cp, x-cp);
+	    }
+	    cp = ++x;
+	    if ((x = index (cp, ',')) != NULL) { /* work phone */
+		if ((work_phone = (char *)malloc (x-cp+1)) != NULL) {
+		    memset (work_phone, 0, x-cp+1);
+		    strncpy (work_phone, cp, x-cp);
+		}
+		cp = ++x;
+		if ((x = index (cp, ',')) != NULL) { /* home phone */
+		    if ((home_phone = (char *)malloc (x-cp+1)) != NULL) {
+			memset (home_phone, 0, x-cp+1);
+			strncpy (home_phone, cp, x-cp);
+		    }
+		    cp = ++x;
+		    if ((x = index (cp, ',')) != NULL) /* other */
+			*x = '\0';
+		    if ((other = (char *)malloc (strlen(cp)+1)) != NULL) {
+			memset (other, 0, strlen(cp)+1);
+			strcpy (other, cp);
+		    }
+		} else { /* no comma, thus string is home phone */
+		    if ((home_phone = (char *)malloc (strlen(cp)+1)) != NULL) {
+			memset (home_phone, 0, strlen(cp)+1);
+			strcpy (home_phone, cp);
+		    }
+		}
+	    }
+	}
+    } else { /* no comma, thus whole string is username */
+	if ((username = (char *)malloc (strlen(cp)+1)) != NULL) {
+	    memset (username, 0, strlen(cp)+1);
+	    strcpy (username, cp);
+	}
+    }
 
     if ((prog_config.no_finger_file != NULL) 
 	&& (strlen(pwent->pw_dir)+strlen(prog_config.no_finger_file)+1 < sizeof(fn)))
