@@ -78,10 +78,9 @@ void process_display(void)
 	    snprintf(console, sizeof(console), "(%s)", tty_list[i].locale);
 
 	if (strlen((char *) tty_list[i].username) > 1) {
-	    char username[STRLEN], dummy[STRLEN], ru[8], fn[STRLEN];
+	    char *username=NULL;
+	    char ru[8], fn[STRLEN];
 
-	    memset(username, 0, sizeof (username));
-	    memset(dummy, 0, sizeof (dummy));
 	    memset(ru, 0, sizeof (ru));
 	    memset(fn, 0, sizeof (fn));
 
@@ -90,7 +89,13 @@ void process_display(void)
 	    pwent = getpwnam((char *) ru);
 
 	    if (pwent) {
-		sscanf(pwent->pw_gecos, "%[^,],%[^\r\n]\r\n", username, dummy);
+		cp = pwent->pw_gecos;
+		if ((x = index (pwent->pw_gecos, ',')) != NULL) /* username */
+		    *x = '\0';
+		    if ((username = (char *)malloc (strlen(cp)+1)) != NULL) {
+			memset (username, 0, strlen(cp)+1);
+			strcpy (username, cp);
+		    }
 		snprintf(fn, sizeof(fn), "%s/.nofinger", pwent->pw_dir);
 	    }
 
@@ -99,7 +104,7 @@ void process_display(void)
 		if (!exist((char *) fn)) {
 		    if (idle) {
 			printf("%-8.8s %-30.30s %8.8s ",
-			       ru, username, idle);
+			       ru, username?username:"", idle);
 
 			printf("%3.3s %-25.25s\n",
 			       (char *) tty_list[i].tty, console);
