@@ -10,19 +10,19 @@
 #include <unistd.h>
 #include <time.h>
 
-void show_idle(char *tty)
+char *calc_idle(char *tty)
 {
     struct stat buf;
     time_t cur_time;
     long diff_time;
     int min, hour, day;
-    char idledisp[80];
-    char dev_file[80];
+    static char idledisp[STRLEN];
+    char dev_file[STRLEN];
 
-    bzero(idledisp, 80);
-    bzero(dev_file, 80);
+    memset(idledisp, 0, sizeof (idledisp));
+    memset(dev_file, 0, sizeof (dev_file));
 
-    sprintf(dev_file, "/dev/%s", tty);
+    snprintf(dev_file, sizeof (dev_file), "/dev/%s", tty);
 
     stat((char *) dev_file, &buf);
     cur_time = time(NULL);
@@ -43,6 +43,12 @@ void show_idle(char *tty)
 	diff_time -= day * 86400;
     }
 
+    if (day) {
+	if (no_idle) return NULL;
+	snprintf(idledisp, sizeof (idledisp), "%1dd ", day);
+	return idledisp;
+    }
+
     if (hour) {
 	hour = diff_time / 3600;
 	diff_time -= hour * 3600;
@@ -53,18 +59,20 @@ void show_idle(char *tty)
 	diff_time -= min * 60;
     }
 
-    idledisp[0] = 0;
-
-    if (day) {
-	sprintf(idledisp, "%1dd ", day);
-    }
-
     if (hour || min) {
 	if (day)
-	    sprintf(idledisp, "%02d:%02d", hour, min);
+	    snprintf(idledisp, sizeof (idledisp), "%02d:%02d", hour, min);
 	else
-	    sprintf(idledisp, "%d:%02d", hour, min);
+	    snprintf(idledisp, sizeof (idledisp), "%d:%02d", hour, min);
     }
 
-    printf("%8.8s ", idledisp);
+    return idledisp;
 }
+
+/*
+ * Local variables:
+ *  c-indent-level: 4
+ *  c-basic-offset: 4
+ *  tab-width: 8
+ * End:
+ */
