@@ -7,6 +7,7 @@
 #include "proto.h"
 
 int display_type;
+int no_idle = 0;
 
 void give_help(void)
 {
@@ -16,6 +17,7 @@ void give_help(void)
     printf("\t-b\tGive BSD/OS-type finger output\n");
 */
     printf("\t-c\tGive standard CFINGERD (custom) output\n");
+    printf("\t-n\tList only people idle less than one day\n");
 /*
     printf("\t-g\tGive GNU-FINGER display output\n");
     printf("\t-l\tGive standard LINUX finger output (as if there is any)\n");
@@ -30,11 +32,24 @@ void give_help(void)
 
 void handle_options(int argc, char *argv[])
 {
-    if (!strncmp(argv[1], "-c", 2)) {
-	display_type = DISPLAY_CFINGERD;
-	return;
-    }
+    int i;
 
-    if (argc > 1)
-	give_help();
+    for (i=1;i<argc;i++) {
+	if (!strcmp(argv[i], "-c"))
+	    display_type = DISPLAY_CFINGERD;
+	else if (!strcmp(argv[i], "-n"))
+	    no_idle = 1;
+	else {
+	    give_help();
+	    return;
+	}
+    }
 }
+
+/*
+ * Local variables:
+ *  c-indent-level: 4
+ *  c-basic-offset: 4
+ *  tab-width: 8
+ * End:
+ */
